# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V1ClaimSource(BaseModel):
    """
    ClaimSource describes a reference to a ResourceClaim.  Exactly one of these fields should be set.  Consumers of this type must treat an empty object as if it has an unknown value.  # noqa: E501
    """
    resource_claim_name: Optional[StrictStr] = Field(None, alias="resourceClaimName", description="ResourceClaimName is the name of a ResourceClaim object in the same namespace as this pod.")
    resource_claim_template_name: Optional[StrictStr] = Field(None, alias="resourceClaimTemplateName", description="ResourceClaimTemplateName is the name of a ResourceClaimTemplate object in the same namespace as this pod.  The template will be used to create a new ResourceClaim, which will be bound to this pod. When this pod is deleted, the ResourceClaim will also be deleted. The pod name and resource name, along with a generated component, will be used to form a unique name for the ResourceClaim, which will be recorded in pod.status.resourceClaimStatuses.  This field is immutable and no changes will be made to the corresponding ResourceClaim by the control plane after creating the ResourceClaim.")
    __properties = ["resourceClaimName", "resourceClaimTemplateName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ClaimSource:
        """Create an instance of V1ClaimSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ClaimSource:
        """Create an instance of V1ClaimSource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ClaimSource.parse_obj(obj)

        _obj = V1ClaimSource.parse_obj({
            "resource_claim_name": obj.get("resourceClaimName"),
            "resource_claim_template_name": obj.get("resourceClaimTemplateName")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictStr, conbytes, constr, validator
from .apiextensions_v1_service_reference import ApiextensionsV1ServiceReference

class ApiextensionsV1WebhookClientConfig(BaseModel):
    """
    WebhookClientConfig contains the information to make a TLS connection with the webhook.  # noqa: E501
    """
    ca_bundle: Optional[Union[conbytes(strict=True), constr(strict=True)]] = Field(None, alias="caBundle", description="caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used.")
    service: Optional[ApiextensionsV1ServiceReference] = None
    url: Optional[StrictStr] = Field(None, description="url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.  The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.  Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.  The scheme must be \"https\"; the URL must begin with \"https://\".  A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.  Attempting to use a user or basic auth e.g. \"user:password@\" is not allowed. Fragments (\"#...\") and query parameters (\"?...\") are not allowed, either.")
    __properties = ["caBundle", "service", "url"]

    @validator('ca_bundle')
    def ca_bundle_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$", value):
            raise ValueError(r"must validate the regular expression /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiextensionsV1WebhookClientConfig:
        """Create an instance of ApiextensionsV1WebhookClientConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of service
        if self.service:
            _dict['service'] = self.service.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiextensionsV1WebhookClientConfig:
        """Create an instance of ApiextensionsV1WebhookClientConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiextensionsV1WebhookClientConfig.parse_obj(obj)

        _obj = ApiextensionsV1WebhookClientConfig.parse_obj({
            "ca_bundle": obj.get("caBundle"),
            "service": ApiextensionsV1ServiceReference.from_dict(obj.get("service")) if obj.get("service") is not None else None,
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from .v1_endpoint_subset import V1EndpointSubset
from .v1_object_meta import V1ObjectMeta

class V1Endpoints(BaseModel):
    """
    Endpoints is a collection of endpoints that implement the actual service. Example:    Name: \"mysvc\",   Subsets: [     {       Addresses: [{\"ip\": \"10.10.1.1\"}, {\"ip\": \"10.10.2.2\"}],       Ports: [{\"name\": \"a\", \"port\": 8675}, {\"name\": \"b\", \"port\": 309}]     },     {       Addresses: [{\"ip\": \"10.10.3.3\"}],       Ports: [{\"name\": \"a\", \"port\": 93}, {\"name\": \"b\", \"port\": 76}]     },  ]  # noqa: E501
    """
    api_version: Optional[StrictStr] = Field(None, alias="apiVersion", description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources")
    kind: Optional[StrictStr] = Field(None, description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds")
    metadata: Optional[V1ObjectMeta] = None
    subsets: Optional[conlist(V1EndpointSubset)] = Field(None, description="The set of all endpoints is the union of all subsets. Addresses are placed into subsets according to the IPs they share. A single address with multiple ports, some of which are ready and some of which are not (because they come from different containers) will result in the address being displayed in different subsets for the different ports. No address will appear in both Addresses and NotReadyAddresses in the same subset. Sets of addresses and ports that comprise a service.")
    __properties = ["apiVersion", "kind", "metadata", "subsets"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Endpoints:
        """Create an instance of V1Endpoints from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in subsets (list)
        _items = []
        if self.subsets:
            for _item in self.subsets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['subsets'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Endpoints:
        """Create an instance of V1Endpoints from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1Endpoints.parse_obj(obj)

        _obj = V1Endpoints.parse_obj({
            "api_version": obj.get("apiVersion"),
            "kind": obj.get("kind"),
            "metadata": V1ObjectMeta.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None,
            "subsets": [V1EndpointSubset.from_dict(_item) for _item in obj.get("subsets")] if obj.get("subsets") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, conlist
from .v1_object_reference import V1ObjectReference

class V1CronJobStatus(BaseModel):
    """
    CronJobStatus represents the current state of a cron job.  # noqa: E501
    """
    active: Optional[conlist(V1ObjectReference)] = Field(None, description="A list of pointers to currently running jobs.")
    last_schedule_time: Optional[datetime] = Field(None, alias="lastScheduleTime", description="Information when was the last time the job was successfully scheduled.")
    last_successful_time: Optional[datetime] = Field(None, alias="lastSuccessfulTime", description="Information when was the last time the job successfully completed.")
    __properties = ["active", "lastScheduleTime", "lastSuccessfulTime"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CronJobStatus:
        """Create an instance of V1CronJobStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in active (list)
        _items = []
        if self.active:
            for _item in self.active:
                if _item:
                    _items.append(_item.to_dict())
            _dict['active'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CronJobStatus:
        """Create an instance of V1CronJobStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CronJobStatus.parse_obj(obj)

        _obj = V1CronJobStatus.parse_obj({
            "active": [V1ObjectReference.from_dict(_item) for _item in obj.get("active")] if obj.get("active") is not None else None,
            "last_schedule_time": obj.get("lastScheduleTime"),
            "last_successful_time": obj.get("lastSuccessfulTime")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class V1LeaseSpec(BaseModel):
    """
    LeaseSpec is a specification of a Lease.  # noqa: E501
    """
    acquire_time: Optional[datetime] = Field(None, alias="acquireTime", description="acquireTime is a time when the current lease was acquired.")
    holder_identity: Optional[StrictStr] = Field(None, alias="holderIdentity", description="holderIdentity contains the identity of the holder of a current lease.")
    lease_duration_seconds: Optional[StrictInt] = Field(None, alias="leaseDurationSeconds", description="leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measure against time of last observed renewTime.")
    lease_transitions: Optional[StrictInt] = Field(None, alias="leaseTransitions", description="leaseTransitions is the number of transitions of a lease between holders.")
    renew_time: Optional[datetime] = Field(None, alias="renewTime", description="renewTime is a time when the current holder of a lease has last updated the lease.")
    __properties = ["acquireTime", "holderIdentity", "leaseDurationSeconds", "leaseTransitions", "renewTime"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1LeaseSpec:
        """Create an instance of V1LeaseSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1LeaseSpec:
        """Create an instance of V1LeaseSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1LeaseSpec.parse_obj(obj)

        _obj = V1LeaseSpec.parse_obj({
            "acquire_time": obj.get("acquireTime"),
            "holder_identity": obj.get("holderIdentity"),
            "lease_duration_seconds": obj.get("leaseDurationSeconds"),
            "lease_transitions": obj.get("leaseTransitions"),
            "renew_time": obj.get("renewTime")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from .v1_secret_reference import V1SecretReference

class V1CephFSPersistentVolumeSource(BaseModel):
    """
    Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.  # noqa: E501
    """
    monitors: conlist(StrictStr) = Field(..., description="monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it")
    path: Optional[StrictStr] = Field(None, description="path is Optional: Used as the mounted root, rather than the full Ceph tree, default is /")
    read_only: Optional[StrictBool] = Field(None, alias="readOnly", description="readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it")
    secret_file: Optional[StrictStr] = Field(None, alias="secretFile", description="secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it")
    secret_ref: Optional[V1SecretReference] = Field(None, alias="secretRef")
    user: Optional[StrictStr] = Field(None, description="user is Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it")
    __properties = ["monitors", "path", "readOnly", "secretFile", "secretRef", "user"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CephFSPersistentVolumeSource:
        """Create an instance of V1CephFSPersistentVolumeSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of secret_ref
        if self.secret_ref:
            _dict['secretRef'] = self.secret_ref.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CephFSPersistentVolumeSource:
        """Create an instance of V1CephFSPersistentVolumeSource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CephFSPersistentVolumeSource.parse_obj(obj)

        _obj = V1CephFSPersistentVolumeSource.parse_obj({
            "monitors": obj.get("monitors"),
            "path": obj.get("path"),
            "read_only": obj.get("readOnly"),
            "secret_file": obj.get("secretFile"),
            "secret_ref": V1SecretReference.from_dict(obj.get("secretRef")) if obj.get("secretRef") is not None else None,
            "user": obj.get("user")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V1alpha1ClusterTrustBundleSpec(BaseModel):
    """
    ClusterTrustBundleSpec contains the signer and trust anchors.  # noqa: E501
    """
    signer_name: Optional[StrictStr] = Field(None, alias="signerName", description="signerName indicates the associated signer, if any.  In order to create or update a ClusterTrustBundle that sets signerName, you must have the following cluster-scoped permission: group=certificates.k8s.io resource=signers resourceName=<the signer name> verb=attest.  If signerName is not empty, then the ClusterTrustBundle object must be named with the signer name as a prefix (translating slashes to colons). For example, for the signer name `example.com/foo`, valid ClusterTrustBundle object names include `example.com:foo:abc` and `example.com:foo:v1`.  If signerName is empty, then the ClusterTrustBundle object's name must not have such a prefix.  List/watch requests for ClusterTrustBundles can filter on this field using a `spec.signerName=NAME` field selector.")
    trust_bundle: StrictStr = Field(..., alias="trustBundle", description="trustBundle contains the individual X.509 trust anchors for this bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.  The data must consist only of PEM certificate blocks that parse as valid X.509 certificates.  Each certificate must include a basic constraints extension with the CA bit set.  The API server will reject objects that contain duplicate certificates, or that use PEM block headers.  Users of ClusterTrustBundles, including Kubelet, are free to reorder and deduplicate certificate blocks in this file according to their own logic, as well as to drop PEM block headers and inter-block data.")
    __properties = ["signerName", "trustBundle"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1alpha1ClusterTrustBundleSpec:
        """Create an instance of V1alpha1ClusterTrustBundleSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1alpha1ClusterTrustBundleSpec:
        """Create an instance of V1alpha1ClusterTrustBundleSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1alpha1ClusterTrustBundleSpec.parse_obj(obj)

        _obj = V1alpha1ClusterTrustBundleSpec.parse_obj({
            "signer_name": obj.get("signerName"),
            "trust_bundle": obj.get("trustBundle")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from .v1_pod_template_spec import V1PodTemplateSpec

class V1ReplicationControllerSpec(BaseModel):
    """
    ReplicationControllerSpec is the specification of a replication controller.  # noqa: E501
    """
    min_ready_seconds: Optional[StrictInt] = Field(None, alias="minReadySeconds", description="Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)")
    replicas: Optional[StrictInt] = Field(None, description="Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller")
    selector: Optional[Dict[str, StrictStr]] = Field(None, description="Selector is a label query over pods that should match the Replicas count. If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors")
    template: Optional[V1PodTemplateSpec] = None
    __properties = ["minReadySeconds", "replicas", "selector", "template"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ReplicationControllerSpec:
        """Create an instance of V1ReplicationControllerSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ReplicationControllerSpec:
        """Create an instance of V1ReplicationControllerSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ReplicationControllerSpec.parse_obj(obj)

        _obj = V1ReplicationControllerSpec.parse_obj({
            "min_ready_seconds": obj.get("minReadySeconds"),
            "replicas": obj.get("replicas"),
            "selector": obj.get("selector"),
            "template": V1PodTemplateSpec.from_dict(obj.get("template")) if obj.get("template") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from .v1beta3_flow_distinguisher_method import V1beta3FlowDistinguisherMethod
from .v1beta3_policy_rules_with_subjects import V1beta3PolicyRulesWithSubjects
from .v1beta3_priority_level_configuration_reference import V1beta3PriorityLevelConfigurationReference

class V1beta3FlowSchemaSpec(BaseModel):
    """
    FlowSchemaSpec describes how the FlowSchema's specification looks like.  # noqa: E501
    """
    distinguisher_method: Optional[V1beta3FlowDistinguisherMethod] = Field(None, alias="distinguisherMethod")
    matching_precedence: Optional[StrictInt] = Field(None, alias="matchingPrecedence", description="`matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default.")
    priority_level_configuration: V1beta3PriorityLevelConfigurationReference = Field(..., alias="priorityLevelConfiguration")
    rules: Optional[conlist(V1beta3PolicyRulesWithSubjects)] = Field(None, description="`rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema.")
    __properties = ["distinguisherMethod", "matchingPrecedence", "priorityLevelConfiguration", "rules"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1beta3FlowSchemaSpec:
        """Create an instance of V1beta3FlowSchemaSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of distinguisher_method
        if self.distinguisher_method:
            _dict['distinguisherMethod'] = self.distinguisher_method.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority_level_configuration
        if self.priority_level_configuration:
            _dict['priorityLevelConfiguration'] = self.priority_level_configuration.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in rules (list)
        _items = []
        if self.rules:
            for _item in self.rules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['rules'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1beta3FlowSchemaSpec:
        """Create an instance of V1beta3FlowSchemaSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1beta3FlowSchemaSpec.parse_obj(obj)

        _obj = V1beta3FlowSchemaSpec.parse_obj({
            "distinguisher_method": V1beta3FlowDistinguisherMethod.from_dict(obj.get("distinguisherMethod")) if obj.get("distinguisherMethod") is not None else None,
            "matching_precedence": obj.get("matchingPrecedence"),
            "priority_level_configuration": V1beta3PriorityLevelConfigurationReference.from_dict(obj.get("priorityLevelConfiguration")) if obj.get("priorityLevelConfiguration") is not None else None,
            "rules": [V1beta3PolicyRulesWithSubjects.from_dict(_item) for _item in obj.get("rules")] if obj.get("rules") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class V1WindowsSecurityContextOptions(BaseModel):
    """
    WindowsSecurityContextOptions contain Windows-specific options and credentials.  # noqa: E501
    """
    gmsa_credential_spec: Optional[StrictStr] = Field(None, alias="gmsaCredentialSpec", description="GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field.")
    gmsa_credential_spec_name: Optional[StrictStr] = Field(None, alias="gmsaCredentialSpecName", description="GMSACredentialSpecName is the name of the GMSA credential spec to use.")
    host_process: Optional[StrictBool] = Field(None, alias="hostProcess", description="HostProcess determines if a container should be run as a 'Host Process' container. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers). In addition, if HostProcess is true then HostNetwork must also be set to true.")
    run_as_user_name: Optional[StrictStr] = Field(None, alias="runAsUserName", description="The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.")
    __properties = ["gmsaCredentialSpec", "gmsaCredentialSpecName", "hostProcess", "runAsUserName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1WindowsSecurityContextOptions:
        """Create an instance of V1WindowsSecurityContextOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1WindowsSecurityContextOptions:
        """Create an instance of V1WindowsSecurityContextOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1WindowsSecurityContextOptions.parse_obj(obj)

        _obj = V1WindowsSecurityContextOptions.parse_obj({
            "gmsa_credential_spec": obj.get("gmsaCredentialSpec"),
            "gmsa_credential_spec_name": obj.get("gmsaCredentialSpecName"),
            "host_process": obj.get("hostProcess"),
            "run_as_user_name": obj.get("runAsUserName")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from .v1_deployment_condition import V1DeploymentCondition

class V1DeploymentStatus(BaseModel):
    """
    DeploymentStatus is the most recently observed status of the Deployment.  # noqa: E501
    """
    available_replicas: Optional[StrictInt] = Field(None, alias="availableReplicas", description="Total number of available pods (ready for at least minReadySeconds) targeted by this deployment.")
    collision_count: Optional[StrictInt] = Field(None, alias="collisionCount", description="Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet.")
    conditions: Optional[conlist(V1DeploymentCondition)] = Field(None, description="Represents the latest available observations of a deployment's current state.")
    observed_generation: Optional[StrictInt] = Field(None, alias="observedGeneration", description="The generation observed by the deployment controller.")
    ready_replicas: Optional[StrictInt] = Field(None, alias="readyReplicas", description="readyReplicas is the number of pods targeted by this Deployment with a Ready Condition.")
    replicas: Optional[StrictInt] = Field(None, description="Total number of non-terminated pods targeted by this deployment (their labels match the selector).")
    unavailable_replicas: Optional[StrictInt] = Field(None, alias="unavailableReplicas", description="Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created.")
    updated_replicas: Optional[StrictInt] = Field(None, alias="updatedReplicas", description="Total number of non-terminated pods targeted by this deployment that have the desired template spec.")
    __properties = ["availableReplicas", "collisionCount", "conditions", "observedGeneration", "readyReplicas", "replicas", "unavailableReplicas", "updatedReplicas"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1DeploymentStatus:
        """Create an instance of V1DeploymentStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item in self.conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['conditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1DeploymentStatus:
        """Create an instance of V1DeploymentStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1DeploymentStatus.parse_obj(obj)

        _obj = V1DeploymentStatus.parse_obj({
            "available_replicas": obj.get("availableReplicas"),
            "collision_count": obj.get("collisionCount"),
            "conditions": [V1DeploymentCondition.from_dict(_item) for _item in obj.get("conditions")] if obj.get("conditions") is not None else None,
            "observed_generation": obj.get("observedGeneration"),
            "ready_replicas": obj.get("readyReplicas"),
            "replicas": obj.get("replicas"),
            "unavailable_replicas": obj.get("unavailableReplicas"),
            "updated_replicas": obj.get("updatedReplicas")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt
from .v1_exec_action import V1ExecAction
from .v1_grpc_action import V1GRPCAction
from .v1_http_get_action import V1HTTPGetAction
from .v1_tcp_socket_action import V1TCPSocketAction

class V1Probe(BaseModel):
    """
    Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.  # noqa: E501
    """
    var_exec: Optional[V1ExecAction] = Field(None, alias="exec")
    failure_threshold: Optional[StrictInt] = Field(None, alias="failureThreshold", description="Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.")
    grpc: Optional[V1GRPCAction] = None
    http_get: Optional[V1HTTPGetAction] = Field(None, alias="httpGet")
    initial_delay_seconds: Optional[StrictInt] = Field(None, alias="initialDelaySeconds", description="Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes")
    period_seconds: Optional[StrictInt] = Field(None, alias="periodSeconds", description="How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.")
    success_threshold: Optional[StrictInt] = Field(None, alias="successThreshold", description="Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.")
    tcp_socket: Optional[V1TCPSocketAction] = Field(None, alias="tcpSocket")
    termination_grace_period_seconds: Optional[StrictInt] = Field(None, alias="terminationGracePeriodSeconds", description="Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.")
    timeout_seconds: Optional[StrictInt] = Field(None, alias="timeoutSeconds", description="Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes")
    __properties = ["exec", "failureThreshold", "grpc", "httpGet", "initialDelaySeconds", "periodSeconds", "successThreshold", "tcpSocket", "terminationGracePeriodSeconds", "timeoutSeconds"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Probe:
        """Create an instance of V1Probe from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_exec
        if self.var_exec:
            _dict['exec'] = self.var_exec.to_dict()
        # override the default output from pydantic by calling `to_dict()` of grpc
        if self.grpc:
            _dict['grpc'] = self.grpc.to_dict()
        # override the default output from pydantic by calling `to_dict()` of http_get
        if self.http_get:
            _dict['httpGet'] = self.http_get.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tcp_socket
        if self.tcp_socket:
            _dict['tcpSocket'] = self.tcp_socket.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Probe:
        """Create an instance of V1Probe from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1Probe.parse_obj(obj)

        _obj = V1Probe.parse_obj({
            "var_exec": V1ExecAction.from_dict(obj.get("exec")) if obj.get("exec") is not None else None,
            "failure_threshold": obj.get("failureThreshold"),
            "grpc": V1GRPCAction.from_dict(obj.get("grpc")) if obj.get("grpc") is not None else None,
            "http_get": V1HTTPGetAction.from_dict(obj.get("httpGet")) if obj.get("httpGet") is not None else None,
            "initial_delay_seconds": obj.get("initialDelaySeconds"),
            "period_seconds": obj.get("periodSeconds"),
            "success_threshold": obj.get("successThreshold"),
            "tcp_socket": V1TCPSocketAction.from_dict(obj.get("tcpSocket")) if obj.get("tcpSocket") is not None else None,
            "termination_grace_period_seconds": obj.get("terminationGracePeriodSeconds"),
            "timeout_seconds": obj.get("timeoutSeconds")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist

class V1PodFailurePolicyOnExitCodesRequirement(BaseModel):
    """
    PodFailurePolicyOnExitCodesRequirement describes the requirement for handling a failed pod based on its container exit codes. In particular, it lookups the .state.terminated.exitCode for each app container and init container status, represented by the .status.containerStatuses and .status.initContainerStatuses fields in the Pod status, respectively. Containers completed with success (exit code 0) are excluded from the requirement check.  # noqa: E501
    """
    container_name: Optional[StrictStr] = Field(None, alias="containerName", description="Restricts the check for exit codes to the container with the specified name. When null, the rule applies to all containers. When specified, it should match one the container or initContainer names in the pod template.")
    operator: StrictStr = Field(..., description="Represents the relationship between the container exit code(s) and the specified values. Containers completed with success (exit code 0) are excluded from the requirement check. Possible values are:  - In: the requirement is satisfied if at least one container exit code   (might be multiple if there are multiple containers not restricted   by the 'containerName' field) is in the set of specified values. - NotIn: the requirement is satisfied if at least one container exit code   (might be multiple if there are multiple containers not restricted   by the 'containerName' field) is not in the set of specified values. Additional values are considered to be added in the future. Clients should react to an unknown operator by assuming the requirement is not satisfied.")
    values: conlist(StrictInt) = Field(..., description="Specifies the set of values. Each returned container exit code (might be multiple in case of multiple containers) is checked against this set of values with respect to the operator. The list of values must be ordered and must not contain duplicates. Value '0' cannot be used for the In operator. At least one element is required. At most 255 elements are allowed.")
    __properties = ["containerName", "operator", "values"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1PodFailurePolicyOnExitCodesRequirement:
        """Create an instance of V1PodFailurePolicyOnExitCodesRequirement from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1PodFailurePolicyOnExitCodesRequirement:
        """Create an instance of V1PodFailurePolicyOnExitCodesRequirement from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1PodFailurePolicyOnExitCodesRequirement.parse_obj(obj)

        _obj = V1PodFailurePolicyOnExitCodesRequirement.parse_obj({
            "container_name": obj.get("containerName"),
            "operator": obj.get("operator"),
            "values": obj.get("values")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V1CustomResourceSubresourceScale(BaseModel):
    """
    CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources.  # noqa: E501
    """
    label_selector_path: Optional[StrictStr] = Field(None, alias="labelSelectorPath", description="labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string.")
    spec_replicas_path: StrictStr = Field(..., alias="specReplicasPath", description="specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET.")
    status_replicas_path: StrictStr = Field(..., alias="statusReplicasPath", description="statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0.")
    __properties = ["labelSelectorPath", "specReplicasPath", "statusReplicasPath"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CustomResourceSubresourceScale:
        """Create an instance of V1CustomResourceSubresourceScale from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CustomResourceSubresourceScale:
        """Create an instance of V1CustomResourceSubresourceScale from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CustomResourceSubresourceScale.parse_obj(obj)

        _obj = V1CustomResourceSubresourceScale.parse_obj({
            "label_selector_path": obj.get("labelSelectorPath"),
            "spec_replicas_path": obj.get("specReplicasPath"),
            "status_replicas_path": obj.get("statusReplicasPath")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from .v1_label_selector import V1LabelSelector
from .v1_typed_local_object_reference import V1TypedLocalObjectReference
from .v1_typed_object_reference import V1TypedObjectReference
from .v1_volume_resource_requirements import V1VolumeResourceRequirements

class V1PersistentVolumeClaimSpec(BaseModel):
    """
    PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes  # noqa: E501
    """
    access_modes: Optional[conlist(StrictStr)] = Field(None, alias="accessModes", description="accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1")
    data_source: Optional[V1TypedLocalObjectReference] = Field(None, alias="dataSource")
    data_source_ref: Optional[V1TypedObjectReference] = Field(None, alias="dataSourceRef")
    resources: Optional[V1VolumeResourceRequirements] = None
    selector: Optional[V1LabelSelector] = None
    storage_class_name: Optional[StrictStr] = Field(None, alias="storageClassName", description="storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1")
    volume_attributes_class_name: Optional[StrictStr] = Field(None, alias="volumeAttributesClassName", description="volumeAttributesClassName may be used to set the VolumeAttributesClass used by this claim. If specified, the CSI driver will create or update the volume with the attributes defined in the corresponding VolumeAttributesClass. This has a different purpose than storageClassName, it can be changed after the claim is created. An empty string value means that no VolumeAttributesClass will be applied to the claim but it's not allowed to reset this field to empty string once it is set. If unspecified and the PersistentVolumeClaim is unbound, the default VolumeAttributesClass will be set by the persistentvolume controller if it exists. If the resource referred to by volumeAttributesClass does not exist, this PersistentVolumeClaim will be set to a Pending state, as reflected by the modifyVolumeStatus field, until such as a resource exists. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#volumeattributesclass (Alpha) Using this field requires the VolumeAttributesClass feature gate to be enabled.")
    volume_mode: Optional[StrictStr] = Field(None, alias="volumeMode", description="volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.")
    volume_name: Optional[StrictStr] = Field(None, alias="volumeName", description="volumeName is the binding reference to the PersistentVolume backing this claim.")
    __properties = ["accessModes", "dataSource", "dataSourceRef", "resources", "selector", "storageClassName", "volumeAttributesClassName", "volumeMode", "volumeName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1PersistentVolumeClaimSpec:
        """Create an instance of V1PersistentVolumeClaimSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of data_source
        if self.data_source:
            _dict['dataSource'] = self.data_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of data_source_ref
        if self.data_source_ref:
            _dict['dataSourceRef'] = self.data_source_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict['resources'] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of selector
        if self.selector:
            _dict['selector'] = self.selector.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1PersistentVolumeClaimSpec:
        """Create an instance of V1PersistentVolumeClaimSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1PersistentVolumeClaimSpec.parse_obj(obj)

        _obj = V1PersistentVolumeClaimSpec.parse_obj({
            "access_modes": obj.get("accessModes"),
            "data_source": V1TypedLocalObjectReference.from_dict(obj.get("dataSource")) if obj.get("dataSource") is not None else None,
            "data_source_ref": V1TypedObjectReference.from_dict(obj.get("dataSourceRef")) if obj.get("dataSourceRef") is not None else None,
            "resources": V1VolumeResourceRequirements.from_dict(obj.get("resources")) if obj.get("resources") is not None else None,
            "selector": V1LabelSelector.from_dict(obj.get("selector")) if obj.get("selector") is not None else None,
            "storage_class_name": obj.get("storageClassName"),
            "volume_attributes_class_name": obj.get("volumeAttributesClassName"),
            "volume_mode": obj.get("volumeMode"),
            "volume_name": obj.get("volumeName")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V1beta1Validation(BaseModel):
    """
    Validation specifies the CEL expression which is used to apply the validation.  # noqa: E501
    """
    expression: StrictStr = Field(..., description="Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables:  - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'namespaceObject' - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - 'variables' - Map of composited variables, from its name to its lazily evaluated value.   For example, a variable named 'foo' can be accessed as 'variables.foo'. - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the   request resource.  The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.  Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:    \"true\", \"false\", \"null\", \"in\", \"as\", \"break\", \"const\", \"continue\", \"else\", \"for\", \"function\", \"if\",    \"import\", \"let\", \"loop\", \"package\", \"namespace\", \"return\". Examples:   - Expression accessing a property named \"namespace\": {\"Expression\": \"object.__namespace__ > 0\"}   - Expression accessing a property named \"x-prop\": {\"Expression\": \"object.x__dash__prop > 0\"}   - Expression accessing a property named \"redact__d\": {\"Expression\": \"object.redact__underscores__d > 0\"}  Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and     non-intersecting elements in `Y` are appended, retaining their partial order.   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with     non-intersecting keys are appended, retaining their partial order. Required.")
    message: Optional[StrictStr] = Field(None, description="Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is \"failed rule: {Rule}\". e.g. \"must be a URL with the host matching spec.host\" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is \"failed Expression: {Expression}\".")
    message_expression: Optional[StrictStr] = Field(None, alias="messageExpression", description="messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: \"object.x must be less than max (\"+string(params.max)+\")\"")
    reason: Optional[StrictStr] = Field(None, description="Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: \"Unauthorized\", \"Forbidden\", \"Invalid\", \"RequestEntityTooLarge\". If not set, StatusReasonInvalid is used in the response to the client.")
    __properties = ["expression", "message", "messageExpression", "reason"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1beta1Validation:
        """Create an instance of V1beta1Validation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1beta1Validation:
        """Create an instance of V1beta1Validation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1beta1Validation.parse_obj(obj)

        _obj = V1beta1Validation.parse_obj({
            "expression": obj.get("expression"),
            "message": obj.get("message"),
            "message_expression": obj.get("messageExpression"),
            "reason": obj.get("reason")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt

class V1beta3QueuingConfiguration(BaseModel):
    """
    QueuingConfiguration holds the configuration parameters for queuing  # noqa: E501
    """
    hand_size: Optional[StrictInt] = Field(None, alias="handSize", description="`handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8.")
    queue_length_limit: Optional[StrictInt] = Field(None, alias="queueLengthLimit", description="`queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50.")
    queues: Optional[StrictInt] = Field(None, description="`queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64.")
    __properties = ["handSize", "queueLengthLimit", "queues"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1beta3QueuingConfiguration:
        """Create an instance of V1beta3QueuingConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1beta3QueuingConfiguration:
        """Create an instance of V1beta3QueuingConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1beta3QueuingConfiguration.parse_obj(obj)

        _obj = V1beta3QueuingConfiguration.parse_obj({
            "hand_size": obj.get("handSize"),
            "queue_length_limit": obj.get("queueLengthLimit"),
            "queues": obj.get("queues")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from .v1_object_reference import V1ObjectReference

class V1EndpointAddress(BaseModel):
    """
    EndpointAddress is a tuple that describes single IP address.  # noqa: E501
    """
    hostname: Optional[StrictStr] = Field(None, description="The Hostname of this endpoint")
    ip: StrictStr = Field(..., description="The IP of this endpoint. May not be loopback (127.0.0.0/8 or ::1), link-local (169.254.0.0/16 or fe80::/10), or link-local multicast (224.0.0.0/24 or ff02::/16).")
    node_name: Optional[StrictStr] = Field(None, alias="nodeName", description="Optional: Node hosting this endpoint. This can be used to determine endpoints local to a node.")
    target_ref: Optional[V1ObjectReference] = Field(None, alias="targetRef")
    __properties = ["hostname", "ip", "nodeName", "targetRef"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1EndpointAddress:
        """Create an instance of V1EndpointAddress from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of target_ref
        if self.target_ref:
            _dict['targetRef'] = self.target_ref.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1EndpointAddress:
        """Create an instance of V1EndpointAddress from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1EndpointAddress.parse_obj(obj)

        _obj = V1EndpointAddress.parse_obj({
            "hostname": obj.get("hostname"),
            "ip": obj.get("ip"),
            "node_name": obj.get("nodeName"),
            "target_ref": V1ObjectReference.from_dict(obj.get("targetRef")) if obj.get("targetRef") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from .v1_server_address_by_client_cidr import V1ServerAddressByClientCIDR

class V1APIVersions(BaseModel):
    """
    APIVersions lists the versions that are available, to allow clients to discover the API at /api, which is the root path of the legacy v1 API.  # noqa: E501
    """
    api_version: Optional[StrictStr] = Field(None, alias="apiVersion", description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources")
    kind: Optional[StrictStr] = Field(None, description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds")
    server_address_by_client_cidrs: conlist(V1ServerAddressByClientCIDR) = Field(..., alias="serverAddressByClientCIDRs", description="a map of client CIDR to server address that is serving this group. This is to help clients reach servers in the most network-efficient way possible. Clients can use the appropriate server address as per the CIDR that they match. In case of multiple matches, clients should use the longest matching CIDR. The server returns only those CIDRs that it thinks that the client can match. For example: the master will return an internal IP CIDR only, if the client reaches the server using an internal IP. Server looks at X-Forwarded-For header or X-Real-Ip header or request.RemoteAddr (in that order) to get the client IP.")
    versions: conlist(StrictStr) = Field(..., description="versions are the api versions that are available.")
    __properties = ["apiVersion", "kind", "serverAddressByClientCIDRs", "versions"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1APIVersions:
        """Create an instance of V1APIVersions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in server_address_by_client_cidrs (list)
        _items = []
        if self.server_address_by_client_cidrs:
            for _item in self.server_address_by_client_cidrs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['serverAddressByClientCIDRs'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1APIVersions:
        """Create an instance of V1APIVersions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1APIVersions.parse_obj(obj)

        _obj = V1APIVersions.parse_obj({
            "api_version": obj.get("apiVersion"),
            "kind": obj.get("kind"),
            "server_address_by_client_cidrs": [V1ServerAddressByClientCIDR.from_dict(_item) for _item in obj.get("serverAddressByClientCIDRs")] if obj.get("serverAddressByClientCIDRs") is not None else None,
            "versions": obj.get("versions")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from .core_v1_event_series import CoreV1EventSeries
from .v1_event_source import V1EventSource
from .v1_object_meta import V1ObjectMeta
from .v1_object_reference import V1ObjectReference

class CoreV1Event(BaseModel):
    """
    Event is a report of an event somewhere in the cluster.  Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data.  # noqa: E501
    """
    action: Optional[StrictStr] = Field(None, description="What action was taken/failed regarding to the Regarding object.")
    api_version: Optional[StrictStr] = Field(None, alias="apiVersion", description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources")
    count: Optional[StrictInt] = Field(None, description="The number of times this event has occurred.")
    event_time: Optional[datetime] = Field(None, alias="eventTime", description="Time when this Event was first observed.")
    first_timestamp: Optional[datetime] = Field(None, alias="firstTimestamp", description="The time at which the event was first recorded. (Time of server receipt is in TypeMeta.)")
    involved_object: V1ObjectReference = Field(..., alias="involvedObject")
    kind: Optional[StrictStr] = Field(None, description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds")
    last_timestamp: Optional[datetime] = Field(None, alias="lastTimestamp", description="The time at which the most recent occurrence of this event was recorded.")
    message: Optional[StrictStr] = Field(None, description="A human-readable description of the status of this operation.")
    metadata: V1ObjectMeta = Field(...)
    reason: Optional[StrictStr] = Field(None, description="This should be a short, machine understandable string that gives the reason for the transition into the object's current status.")
    related: Optional[V1ObjectReference] = None
    reporting_component: Optional[StrictStr] = Field(None, alias="reportingComponent", description="Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`.")
    reporting_instance: Optional[StrictStr] = Field(None, alias="reportingInstance", description="ID of the controller instance, e.g. `kubelet-xyzf`.")
    series: Optional[CoreV1EventSeries] = None
    source: Optional[V1EventSource] = None
    type: Optional[StrictStr] = Field(None, description="Type of this event (Normal, Warning), new types could be added in the future")
    __properties = ["action", "apiVersion", "count", "eventTime", "firstTimestamp", "involvedObject", "kind", "lastTimestamp", "message", "metadata", "reason", "related", "reportingComponent", "reportingInstance", "series", "source", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CoreV1Event:
        """Create an instance of CoreV1Event from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of involved_object
        if self.involved_object:
            _dict['involvedObject'] = self.involved_object.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of related
        if self.related:
            _dict['related'] = self.related.to_dict()
        # override the default output from pydantic by calling `to_dict()` of series
        if self.series:
            _dict['series'] = self.series.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CoreV1Event:
        """Create an instance of CoreV1Event from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CoreV1Event.parse_obj(obj)

        _obj = CoreV1Event.parse_obj({
            "action": obj.get("action"),
            "api_version": obj.get("apiVersion"),
            "count": obj.get("count"),
            "event_time": obj.get("eventTime"),
            "first_timestamp": obj.get("firstTimestamp"),
            "involved_object": V1ObjectReference.from_dict(obj.get("involvedObject")) if obj.get("involvedObject") is not None else None,
            "kind": obj.get("kind"),
            "last_timestamp": obj.get("lastTimestamp"),
            "message": obj.get("message"),
            "metadata": V1ObjectMeta.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None,
            "reason": obj.get("reason"),
            "related": V1ObjectReference.from_dict(obj.get("related")) if obj.get("related") is not None else None,
            "reporting_component": obj.get("reportingComponent"),
            "reporting_instance": obj.get("reportingInstance"),
            "series": CoreV1EventSeries.from_dict(obj.get("series")) if obj.get("series") is not None else None,
            "source": V1EventSource.from_dict(obj.get("source")) if obj.get("source") is not None else None,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from .v1beta1_audit_annotation import V1beta1AuditAnnotation
from .v1beta1_match_condition import V1beta1MatchCondition
from .v1beta1_match_resources import V1beta1MatchResources
from .v1beta1_param_kind import V1beta1ParamKind
from .v1beta1_validation import V1beta1Validation
from .v1beta1_variable import V1beta1Variable

class V1beta1ValidatingAdmissionPolicySpec(BaseModel):
    """
    ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.  # noqa: E501
    """
    audit_annotations: Optional[conlist(V1beta1AuditAnnotation)] = Field(None, alias="auditAnnotations", description="auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.")
    failure_policy: Optional[StrictStr] = Field(None, alias="failurePolicy", description="failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.  A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource.  failurePolicy does not define how validations that evaluate to false are handled.  When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced.  Allowed values are Ignore or Fail. Defaults to Fail.")
    match_conditions: Optional[conlist(V1beta1MatchCondition)] = Field(None, alias="matchConditions", description="MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.  If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.  The exact matching logic is (in order):   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.   3. If any matchCondition evaluates to an error (but none are FALSE):      - If failurePolicy=Fail, reject the request      - If failurePolicy=Ignore, the policy is skipped")
    match_constraints: Optional[V1beta1MatchResources] = Field(None, alias="matchConstraints")
    param_kind: Optional[V1beta1ParamKind] = Field(None, alias="paramKind")
    validations: Optional[conlist(V1beta1Validation)] = Field(None, description="Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required.")
    variables: Optional[conlist(V1beta1Variable)] = Field(None, description="Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under `variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy.  The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.")
    __properties = ["auditAnnotations", "failurePolicy", "matchConditions", "matchConstraints", "paramKind", "validations", "variables"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1beta1ValidatingAdmissionPolicySpec:
        """Create an instance of V1beta1ValidatingAdmissionPolicySpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in audit_annotations (list)
        _items = []
        if self.audit_annotations:
            for _item in self.audit_annotations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['auditAnnotations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in match_conditions (list)
        _items = []
        if self.match_conditions:
            for _item in self.match_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['matchConditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of match_constraints
        if self.match_constraints:
            _dict['matchConstraints'] = self.match_constraints.to_dict()
        # override the default output from pydantic by calling `to_dict()` of param_kind
        if self.param_kind:
            _dict['paramKind'] = self.param_kind.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in validations (list)
        _items = []
        if self.validations:
            for _item in self.validations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['validations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in variables (list)
        _items = []
        if self.variables:
            for _item in self.variables:
                if _item:
                    _items.append(_item.to_dict())
            _dict['variables'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1beta1ValidatingAdmissionPolicySpec:
        """Create an instance of V1beta1ValidatingAdmissionPolicySpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1beta1ValidatingAdmissionPolicySpec.parse_obj(obj)

        _obj = V1beta1ValidatingAdmissionPolicySpec.parse_obj({
            "audit_annotations": [V1beta1AuditAnnotation.from_dict(_item) for _item in obj.get("auditAnnotations")] if obj.get("auditAnnotations") is not None else None,
            "failure_policy": obj.get("failurePolicy"),
            "match_conditions": [V1beta1MatchCondition.from_dict(_item) for _item in obj.get("matchConditions")] if obj.get("matchConditions") is not None else None,
            "match_constraints": V1beta1MatchResources.from_dict(obj.get("matchConstraints")) if obj.get("matchConstraints") is not None else None,
            "param_kind": V1beta1ParamKind.from_dict(obj.get("paramKind")) if obj.get("paramKind") is not None else None,
            "validations": [V1beta1Validation.from_dict(_item) for _item in obj.get("validations")] if obj.get("validations") is not None else None,
            "variables": [V1beta1Variable.from_dict(_item) for _item in obj.get("variables")] if obj.get("variables") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from .v1_csi_node_driver import V1CSINodeDriver

class V1CSINodeSpec(BaseModel):
    """
    CSINodeSpec holds information about the specification of all CSI drivers installed on a node  # noqa: E501
    """
    drivers: conlist(V1CSINodeDriver) = Field(..., description="drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.")
    __properties = ["drivers"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CSINodeSpec:
        """Create an instance of V1CSINodeSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in drivers (list)
        _items = []
        if self.drivers:
            for _item in self.drivers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['drivers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CSINodeSpec:
        """Create an instance of V1CSINodeSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CSINodeSpec.parse_obj(obj)

        _obj = V1CSINodeSpec.parse_obj({
            "drivers": [V1CSINodeDriver.from_dict(_item) for _item in obj.get("drivers")] if obj.get("drivers") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist

class V1CustomResourceDefinitionNames(BaseModel):
    """
    CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition  # noqa: E501
    """
    categories: Optional[conlist(StrictStr)] = Field(None, description="categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`.")
    kind: StrictStr = Field(..., description="kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls.")
    list_kind: Optional[StrictStr] = Field(None, alias="listKind", description="listKind is the serialized kind of the list for this resource. Defaults to \"`kind`List\".")
    plural: StrictStr = Field(..., description="plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase.")
    short_names: Optional[conlist(StrictStr)] = Field(None, alias="shortNames", description="shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase.")
    singular: Optional[StrictStr] = Field(None, description="singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`.")
    __properties = ["categories", "kind", "listKind", "plural", "shortNames", "singular"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CustomResourceDefinitionNames:
        """Create an instance of V1CustomResourceDefinitionNames from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CustomResourceDefinitionNames:
        """Create an instance of V1CustomResourceDefinitionNames from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CustomResourceDefinitionNames.parse_obj(obj)

        _obj = V1CustomResourceDefinitionNames.parse_obj({
            "categories": obj.get("categories"),
            "kind": obj.get("kind"),
            "list_kind": obj.get("listKind"),
            "plural": obj.get("plural"),
            "short_names": obj.get("shortNames"),
            "singular": obj.get("singular")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist

class V1alpha2ResourceClaimSchedulingStatus(BaseModel):
    """
    ResourceClaimSchedulingStatus contains information about one particular ResourceClaim with \"WaitForFirstConsumer\" allocation mode.  # noqa: E501
    """
    name: Optional[StrictStr] = Field(None, description="Name matches the pod.spec.resourceClaims[*].Name field.")
    unsuitable_nodes: Optional[conlist(StrictStr)] = Field(None, alias="unsuitableNodes", description="UnsuitableNodes lists nodes that the ResourceClaim cannot be allocated for.  The size of this field is limited to 128, the same as for PodSchedulingSpec.PotentialNodes. This may get increased in the future, but not reduced.")
    __properties = ["name", "unsuitableNodes"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1alpha2ResourceClaimSchedulingStatus:
        """Create an instance of V1alpha2ResourceClaimSchedulingStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1alpha2ResourceClaimSchedulingStatus:
        """Create an instance of V1alpha2ResourceClaimSchedulingStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1alpha2ResourceClaimSchedulingStatus.parse_obj(obj)

        _obj = V1alpha2ResourceClaimSchedulingStatus.parse_obj({
            "name": obj.get("name"),
            "unsuitable_nodes": obj.get("unsuitableNodes")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from .v1_status_cause import V1StatusCause

class V1StatusDetails(BaseModel):
    """
    StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined.  # noqa: E501
    """
    causes: Optional[conlist(V1StatusCause)] = Field(None, description="The Causes array includes more details associated with the StatusReason failure. Not all StatusReasons may provide detailed causes.")
    group: Optional[StrictStr] = Field(None, description="The group attribute of the resource associated with the status StatusReason.")
    kind: Optional[StrictStr] = Field(None, description="The kind attribute of the resource associated with the status StatusReason. On some operations may differ from the requested resource Kind. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds")
    name: Optional[StrictStr] = Field(None, description="The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described).")
    retry_after_seconds: Optional[StrictInt] = Field(None, alias="retryAfterSeconds", description="If specified, the time in seconds before the operation should be retried. Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action.")
    uid: Optional[StrictStr] = Field(None, description="UID of the resource. (when there is a single resource which can be described). More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids")
    __properties = ["causes", "group", "kind", "name", "retryAfterSeconds", "uid"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1StatusDetails:
        """Create an instance of V1StatusDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in causes (list)
        _items = []
        if self.causes:
            for _item in self.causes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['causes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1StatusDetails:
        """Create an instance of V1StatusDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1StatusDetails.parse_obj(obj)

        _obj = V1StatusDetails.parse_obj({
            "causes": [V1StatusCause.from_dict(_item) for _item in obj.get("causes")] if obj.get("causes") is not None else None,
            "group": obj.get("group"),
            "kind": obj.get("kind"),
            "name": obj.get("name"),
            "retry_after_seconds": obj.get("retryAfterSeconds"),
            "uid": obj.get("uid")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class V1CustomResourceColumnDefinition(BaseModel):
    """
    CustomResourceColumnDefinition specifies a column for server side printing.  # noqa: E501
    """
    description: Optional[StrictStr] = Field(None, description="description is a human readable description of this column.")
    format: Optional[StrictStr] = Field(None, description="format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.")
    json_path: StrictStr = Field(..., alias="jsonPath", description="jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column.")
    name: StrictStr = Field(..., description="name is a human readable name for the column.")
    priority: Optional[StrictInt] = Field(None, description="priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0.")
    type: StrictStr = Field(..., description="type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details.")
    __properties = ["description", "format", "jsonPath", "name", "priority", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CustomResourceColumnDefinition:
        """Create an instance of V1CustomResourceColumnDefinition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CustomResourceColumnDefinition:
        """Create an instance of V1CustomResourceColumnDefinition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CustomResourceColumnDefinition.parse_obj(obj)

        _obj = V1CustomResourceColumnDefinition.parse_obj({
            "description": obj.get("description"),
            "format": obj.get("format"),
            "json_path": obj.get("jsonPath"),
            "name": obj.get("name"),
            "priority": obj.get("priority"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class V1alpha2ResourceClassParametersReference(BaseModel):
    """
    ResourceClassParametersReference contains enough information to let you locate the parameters for a ResourceClass.  # noqa: E501
    """
    api_group: Optional[StrictStr] = Field(None, alias="apiGroup", description="APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources.")
    kind: StrictStr = Field(..., description="Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata.")
    name: StrictStr = Field(..., description="Name is the name of resource being referenced.")
    namespace: Optional[StrictStr] = Field(None, description="Namespace that contains the referenced resource. Must be empty for cluster-scoped resources and non-empty for namespaced resources.")
    __properties = ["apiGroup", "kind", "name", "namespace"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1alpha2ResourceClassParametersReference:
        """Create an instance of V1alpha2ResourceClassParametersReference from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1alpha2ResourceClassParametersReference:
        """Create an instance of V1alpha2ResourceClassParametersReference from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1alpha2ResourceClassParametersReference.parse_obj(obj)

        _obj = V1alpha2ResourceClassParametersReference.parse_obj({
            "api_group": obj.get("apiGroup"),
            "kind": obj.get("kind"),
            "name": obj.get("name"),
            "namespace": obj.get("namespace")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class V1QuobyteVolumeSource(BaseModel):
    """
    Represents a Quobyte mount that lasts the lifetime of a pod. Quobyte volumes do not support ownership management or SELinux relabeling.  # noqa: E501
    """
    group: Optional[StrictStr] = Field(None, description="group to map volume access to Default is no group")
    read_only: Optional[StrictBool] = Field(None, alias="readOnly", description="readOnly here will force the Quobyte volume to be mounted with read-only permissions. Defaults to false.")
    registry: StrictStr = Field(..., description="registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes")
    tenant: Optional[StrictStr] = Field(None, description="tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin")
    user: Optional[StrictStr] = Field(None, description="user to map volume access to Defaults to serivceaccount user")
    volume: StrictStr = Field(..., description="volume is a string that references an already created Quobyte volume by name.")
    __properties = ["group", "readOnly", "registry", "tenant", "user", "volume"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1QuobyteVolumeSource:
        """Create an instance of V1QuobyteVolumeSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1QuobyteVolumeSource:
        """Create an instance of V1QuobyteVolumeSource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1QuobyteVolumeSource.parse_obj(obj)

        _obj = V1QuobyteVolumeSource.parse_obj({
            "group": obj.get("group"),
            "read_only": obj.get("readOnly"),
            "registry": obj.get("registry"),
            "tenant": obj.get("tenant"),
            "user": obj.get("user"),
            "volume": obj.get("volume")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, conlist
from .core_v1_endpoint_port import CoreV1EndpointPort
from .v1_endpoint_address import V1EndpointAddress

class V1EndpointSubset(BaseModel):
    """
    EndpointSubset is a group of addresses with a common set of ports. The expanded set of endpoints is the Cartesian product of Addresses x Ports. For example, given:   {    Addresses: [{\"ip\": \"10.10.1.1\"}, {\"ip\": \"10.10.2.2\"}],    Ports:     [{\"name\": \"a\", \"port\": 8675}, {\"name\": \"b\", \"port\": 309}]  }  The resulting set of endpoints can be viewed as:   a: [ 10.10.1.1:8675, 10.10.2.2:8675 ],  b: [ 10.10.1.1:309, 10.10.2.2:309 ]  # noqa: E501
    """
    addresses: Optional[conlist(V1EndpointAddress)] = Field(None, description="IP addresses which offer the related ports that are marked as ready. These endpoints should be considered safe for load balancers and clients to utilize.")
    not_ready_addresses: Optional[conlist(V1EndpointAddress)] = Field(None, alias="notReadyAddresses", description="IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check.")
    ports: Optional[conlist(CoreV1EndpointPort)] = Field(None, description="Port numbers available on the related IP addresses.")
    __properties = ["addresses", "notReadyAddresses", "ports"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1EndpointSubset:
        """Create an instance of V1EndpointSubset from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in addresses (list)
        _items = []
        if self.addresses:
            for _item in self.addresses:
                if _item:
                    _items.append(_item.to_dict())
            _dict['addresses'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in not_ready_addresses (list)
        _items = []
        if self.not_ready_addresses:
            for _item in self.not_ready_addresses:
                if _item:
                    _items.append(_item.to_dict())
            _dict['notReadyAddresses'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ports (list)
        _items = []
        if self.ports:
            for _item in self.ports:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ports'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1EndpointSubset:
        """Create an instance of V1EndpointSubset from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1EndpointSubset.parse_obj(obj)

        _obj = V1EndpointSubset.parse_obj({
            "addresses": [V1EndpointAddress.from_dict(_item) for _item in obj.get("addresses")] if obj.get("addresses") is not None else None,
            "not_ready_addresses": [V1EndpointAddress.from_dict(_item) for _item in obj.get("notReadyAddresses")] if obj.get("notReadyAddresses") is not None else None,
            "ports": [CoreV1EndpointPort.from_dict(_item) for _item in obj.get("ports")] if obj.get("ports") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class CoreV1EndpointPort(BaseModel):
    """
    EndpointPort is a tuple that describes a single port.  # noqa: E501
    """
    app_protocol: Optional[StrictStr] = Field(None, alias="appProtocol", description="The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:  * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).  * Kubernetes-defined prefixed names:   * 'kubernetes.io/h2c' - HTTP/2 prior knowledge over cleartext as described in https://www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior-   * 'kubernetes.io/ws'  - WebSocket over cleartext as described in https://www.rfc-editor.org/rfc/rfc6455   * 'kubernetes.io/wss' - WebSocket over TLS as described in https://www.rfc-editor.org/rfc/rfc6455  * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.")
    name: Optional[StrictStr] = Field(None, description="The name of this port.  This must match the 'name' field in the corresponding ServicePort. Must be a DNS_LABEL. Optional only if one port is defined.")
    port: StrictInt = Field(..., description="The port number of the endpoint.")
    protocol: Optional[StrictStr] = Field(None, description="The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.")
    __properties = ["appProtocol", "name", "port", "protocol"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CoreV1EndpointPort:
        """Create an instance of CoreV1EndpointPort from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CoreV1EndpointPort:
        """Create an instance of CoreV1EndpointPort from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CoreV1EndpointPort.parse_obj(obj)

        _obj = CoreV1EndpointPort.parse_obj({
            "app_protocol": obj.get("appProtocol"),
            "name": obj.get("name"),
            "port": obj.get("port"),
            "protocol": obj.get("protocol")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field

class V1RollingUpdateDaemonSet(BaseModel):
    """
    Spec to control the desired behavior of daemon set rolling update.  # noqa: E501
    """
    max_surge: Optional[Dict[str, Any]] = Field(None, alias="maxSurge", description="The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up to a minimum of 1. Default value is 0. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their a new pod created before the old pod is marked as deleted. The update starts by launching new pods on 30% of nodes. Once an updated pod is available (Ready for at least minReadySeconds) the old DaemonSet pod on that node is marked deleted. If the old pod becomes unavailable for any reason (Ready transitions to false, is evicted, or is drained) an updated pod is immediatedly created on that node without considering surge limits. Allowing surge implies the possibility that the resources consumed by the daemonset on any given node can double if the readiness check fails, and so resource intensive daemonsets should take into account that they may cause evictions during disruption.")
    max_unavailable: Optional[Dict[str, Any]] = Field(None, alias="maxUnavailable", description="The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0 if MaxSurge is 0 Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.")
    __properties = ["maxSurge", "maxUnavailable"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1RollingUpdateDaemonSet:
        """Create an instance of V1RollingUpdateDaemonSet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1RollingUpdateDaemonSet:
        """Create an instance of V1RollingUpdateDaemonSet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1RollingUpdateDaemonSet.parse_obj(obj)

        _obj = V1RollingUpdateDaemonSet.parse_obj({
            "max_surge": obj.get("maxSurge"),
            "max_unavailable": obj.get("maxUnavailable")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from .v1_job_template_spec import V1JobTemplateSpec

class V1CronJobSpec(BaseModel):
    """
    CronJobSpec describes how the job execution will look like and when it will actually run.  # noqa: E501
    """
    concurrency_policy: Optional[StrictStr] = Field(None, alias="concurrencyPolicy", description="Specifies how to treat concurrent executions of a Job. Valid values are:  - \"Allow\" (default): allows CronJobs to run concurrently; - \"Forbid\": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - \"Replace\": cancels currently running job and replaces it with a new one")
    failed_jobs_history_limit: Optional[StrictInt] = Field(None, alias="failedJobsHistoryLimit", description="The number of failed finished jobs to retain. Value must be non-negative integer. Defaults to 1.")
    job_template: V1JobTemplateSpec = Field(..., alias="jobTemplate")
    schedule: StrictStr = Field(..., description="The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.")
    starting_deadline_seconds: Optional[StrictInt] = Field(None, alias="startingDeadlineSeconds", description="Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones.")
    successful_jobs_history_limit: Optional[StrictInt] = Field(None, alias="successfulJobsHistoryLimit", description="The number of successful finished jobs to retain. Value must be non-negative integer. Defaults to 3.")
    suspend: Optional[StrictBool] = Field(None, description="This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false.")
    time_zone: Optional[StrictStr] = Field(None, alias="timeZone", description="The time zone name for the given schedule, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. If not specified, this will default to the time zone of the kube-controller-manager process. The set of valid time zone names and the time zone offset is loaded from the system-wide time zone database by the API server during CronJob validation and the controller manager during execution. If no system-wide time zone database can be found a bundled version of the database is used instead. If the time zone name becomes invalid during the lifetime of a CronJob or due to a change in host configuration, the controller will stop creating new new Jobs and will create a system event with the reason UnknownTimeZone. More information can be found in https://kubernetes.io/docs/concepts/workloads/controllers/cron-jobs/#time-zones")
    __properties = ["concurrencyPolicy", "failedJobsHistoryLimit", "jobTemplate", "schedule", "startingDeadlineSeconds", "successfulJobsHistoryLimit", "suspend", "timeZone"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1CronJobSpec:
        """Create an instance of V1CronJobSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of job_template
        if self.job_template:
            _dict['jobTemplate'] = self.job_template.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1CronJobSpec:
        """Create an instance of V1CronJobSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1CronJobSpec.parse_obj(obj)

        _obj = V1CronJobSpec.parse_obj({
            "concurrency_policy": obj.get("concurrencyPolicy"),
            "failed_jobs_history_limit": obj.get("failedJobsHistoryLimit"),
            "job_template": V1JobTemplateSpec.from_dict(obj.get("jobTemplate")) if obj.get("jobTemplate") is not None else None,
            "schedule": obj.get("schedule"),
            "starting_deadline_seconds": obj.get("startingDeadlineSeconds"),
            "successful_jobs_history_limit": obj.get("successfulJobsHistoryLimit"),
            "suspend": obj.get("suspend"),
            "time_zone": obj.get("timeZone")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from .v1_aws_elastic_block_store_volume_source import V1AWSElasticBlockStoreVolumeSource
from .v1_azure_disk_volume_source import V1AzureDiskVolumeSource
from .v1_azure_file_volume_source import V1AzureFileVolumeSource
from .v1_ceph_fs_volume_source import V1CephFSVolumeSource
from .v1_cinder_volume_source import V1CinderVolumeSource
from .v1_config_map_volume_source import V1ConfigMapVolumeSource
from .v1_csi_volume_source import V1CSIVolumeSource
from .v1_downward_api_volume_source import V1DownwardAPIVolumeSource
from .v1_empty_dir_volume_source import V1EmptyDirVolumeSource
from .v1_ephemeral_volume_source import V1EphemeralVolumeSource
from .v1_fc_volume_source import V1FCVolumeSource
from .v1_flex_volume_source import V1FlexVolumeSource
from .v1_flocker_volume_source import V1FlockerVolumeSource
from .v1_gce_persistent_disk_volume_source import V1GCEPersistentDiskVolumeSource
from .v1_git_repo_volume_source import V1GitRepoVolumeSource
from .v1_glusterfs_volume_source import V1GlusterfsVolumeSource
from .v1_host_path_volume_source import V1HostPathVolumeSource
from .v1_iscsi_volume_source import V1ISCSIVolumeSource
from .v1_nfs_volume_source import V1NFSVolumeSource
from .v1_persistent_volume_claim_volume_source import V1PersistentVolumeClaimVolumeSource
from .v1_photon_persistent_disk_volume_source import V1PhotonPersistentDiskVolumeSource
from .v1_portworx_volume_source import V1PortworxVolumeSource
from .v1_projected_volume_source import V1ProjectedVolumeSource
from .v1_quobyte_volume_source import V1QuobyteVolumeSource
from .v1_rbd_volume_source import V1RBDVolumeSource
from .v1_scale_io_volume_source import V1ScaleIOVolumeSource
from .v1_secret_volume_source import V1SecretVolumeSource
from .v1_storage_os_volume_source import V1StorageOSVolumeSource
from .v1_vsphere_virtual_disk_volume_source import V1VsphereVirtualDiskVolumeSource

class V1Volume(BaseModel):
    """
    Volume represents a named volume in a pod that may be accessed by any container in the pod.  # noqa: E501
    """
    aws_elastic_block_store: Optional[V1AWSElasticBlockStoreVolumeSource] = Field(None, alias="awsElasticBlockStore")
    azure_disk: Optional[V1AzureDiskVolumeSource] = Field(None, alias="azureDisk")
    azure_file: Optional[V1AzureFileVolumeSource] = Field(None, alias="azureFile")
    cephfs: Optional[V1CephFSVolumeSource] = None
    cinder: Optional[V1CinderVolumeSource] = None
    config_map: Optional[V1ConfigMapVolumeSource] = Field(None, alias="configMap")
    csi: Optional[V1CSIVolumeSource] = None
    downward_api: Optional[V1DownwardAPIVolumeSource] = Field(None, alias="downwardAPI")
    empty_dir: Optional[V1EmptyDirVolumeSource] = Field(None, alias="emptyDir")
    ephemeral: Optional[V1EphemeralVolumeSource] = None
    fc: Optional[V1FCVolumeSource] = None
    flex_volume: Optional[V1FlexVolumeSource] = Field(None, alias="flexVolume")
    flocker: Optional[V1FlockerVolumeSource] = None
    gce_persistent_disk: Optional[V1GCEPersistentDiskVolumeSource] = Field(None, alias="gcePersistentDisk")
    git_repo: Optional[V1GitRepoVolumeSource] = Field(None, alias="gitRepo")
    glusterfs: Optional[V1GlusterfsVolumeSource] = None
    host_path: Optional[V1HostPathVolumeSource] = Field(None, alias="hostPath")
    iscsi: Optional[V1ISCSIVolumeSource] = None
    name: StrictStr = Field(..., description="name of the volume. Must be a DNS_LABEL and unique within the pod. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names")
    nfs: Optional[V1NFSVolumeSource] = None
    persistent_volume_claim: Optional[V1PersistentVolumeClaimVolumeSource] = Field(None, alias="persistentVolumeClaim")
    photon_persistent_disk: Optional[V1PhotonPersistentDiskVolumeSource] = Field(None, alias="photonPersistentDisk")
    portworx_volume: Optional[V1PortworxVolumeSource] = Field(None, alias="portworxVolume")
    projected: Optional[V1ProjectedVolumeSource] = None
    quobyte: Optional[V1QuobyteVolumeSource] = None
    rbd: Optional[V1RBDVolumeSource] = None
    scale_io: Optional[V1ScaleIOVolumeSource] = Field(None, alias="scaleIO")
    secret: Optional[V1SecretVolumeSource] = None
    storageos: Optional[V1StorageOSVolumeSource] = None
    vsphere_volume: Optional[V1VsphereVirtualDiskVolumeSource] = Field(None, alias="vsphereVolume")
    __properties = ["awsElasticBlockStore", "azureDisk", "azureFile", "cephfs", "cinder", "configMap", "csi", "downwardAPI", "emptyDir", "ephemeral", "fc", "flexVolume", "flocker", "gcePersistentDisk", "gitRepo", "glusterfs", "hostPath", "iscsi", "name", "nfs", "persistentVolumeClaim", "photonPersistentDisk", "portworxVolume", "projected", "quobyte", "rbd", "scaleIO", "secret", "storageos", "vsphereVolume"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Volume:
        """Create an instance of V1Volume from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of aws_elastic_block_store
        if self.aws_elastic_block_store:
            _dict['awsElasticBlockStore'] = self.aws_elastic_block_store.to_dict()
        # override the default output from pydantic by calling `to_dict()` of azure_disk
        if self.azure_disk:
            _dict['azureDisk'] = self.azure_disk.to_dict()
        # override the default output from pydantic by calling `to_dict()` of azure_file
        if self.azure_file:
            _dict['azureFile'] = self.azure_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cephfs
        if self.cephfs:
            _dict['cephfs'] = self.cephfs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cinder
        if self.cinder:
            _dict['cinder'] = self.cinder.to_dict()
        # override the default output from pydantic by calling `to_dict()` of config_map
        if self.config_map:
            _dict['configMap'] = self.config_map.to_dict()
        # override the default output from pydantic by calling `to_dict()` of csi
        if self.csi:
            _dict['csi'] = self.csi.to_dict()
        # override the default output from pydantic by calling `to_dict()` of downward_api
        if self.downward_api:
            _dict['downwardAPI'] = self.downward_api.to_dict()
        # override the default output from pydantic by calling `to_dict()` of empty_dir
        if self.empty_dir:
            _dict['emptyDir'] = self.empty_dir.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ephemeral
        if self.ephemeral:
            _dict['ephemeral'] = self.ephemeral.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fc
        if self.fc:
            _dict['fc'] = self.fc.to_dict()
        # override the default output from pydantic by calling `to_dict()` of flex_volume
        if self.flex_volume:
            _dict['flexVolume'] = self.flex_volume.to_dict()
        # override the default output from pydantic by calling `to_dict()` of flocker
        if self.flocker:
            _dict['flocker'] = self.flocker.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gce_persistent_disk
        if self.gce_persistent_disk:
            _dict['gcePersistentDisk'] = self.gce_persistent_disk.to_dict()
        # override the default output from pydantic by calling `to_dict()` of git_repo
        if self.git_repo:
            _dict['gitRepo'] = self.git_repo.to_dict()
        # override the default output from pydantic by calling `to_dict()` of glusterfs
        if self.glusterfs:
            _dict['glusterfs'] = self.glusterfs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of host_path
        if self.host_path:
            _dict['hostPath'] = self.host_path.to_dict()
        # override the default output from pydantic by calling `to_dict()` of iscsi
        if self.iscsi:
            _dict['iscsi'] = self.iscsi.to_dict()
        # override the default output from pydantic by calling `to_dict()` of nfs
        if self.nfs:
            _dict['nfs'] = self.nfs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of persistent_volume_claim
        if self.persistent_volume_claim:
            _dict['persistentVolumeClaim'] = self.persistent_volume_claim.to_dict()
        # override the default output from pydantic by calling `to_dict()` of photon_persistent_disk
        if self.photon_persistent_disk:
            _dict['photonPersistentDisk'] = self.photon_persistent_disk.to_dict()
        # override the default output from pydantic by calling `to_dict()` of portworx_volume
        if self.portworx_volume:
            _dict['portworxVolume'] = self.portworx_volume.to_dict()
        # override the default output from pydantic by calling `to_dict()` of projected
        if self.projected:
            _dict['projected'] = self.projected.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quobyte
        if self.quobyte:
            _dict['quobyte'] = self.quobyte.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rbd
        if self.rbd:
            _dict['rbd'] = self.rbd.to_dict()
        # override the default output from pydantic by calling `to_dict()` of scale_io
        if self.scale_io:
            _dict['scaleIO'] = self.scale_io.to_dict()
        # override the default output from pydantic by calling `to_dict()` of secret
        if self.secret:
            _dict['secret'] = self.secret.to_dict()
        # override the default output from pydantic by calling `to_dict()` of storageos
        if self.storageos:
            _dict['storageos'] = self.storageos.to_dict()
        # override the default output from pydantic by calling `to_dict()` of vsphere_volume
        if self.vsphere_volume:
            _dict['vsphereVolume'] = self.vsphere_volume.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Volume:
        """Create an instance of V1Volume from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1Volume.parse_obj(obj)

        _obj = V1Volume.parse_obj({
            "aws_elastic_block_store": V1AWSElasticBlockStoreVolumeSource.from_dict(obj.get("awsElasticBlockStore")) if obj.get("awsElasticBlockStore") is not None else None,
            "azure_disk": V1AzureDiskVolumeSource.from_dict(obj.get("azureDisk")) if obj.get("azureDisk") is not None else None,
            "azure_file": V1AzureFileVolumeSource.from_dict(obj.get("azureFile")) if obj.get("azureFile") is not None else None,
            "cephfs": V1CephFSVolumeSource.from_dict(obj.get("cephfs")) if obj.get("cephfs") is not None else None,
            "cinder": V1CinderVolumeSource.from_dict(obj.get("cinder")) if obj.get("cinder") is not None else None,
            "config_map": V1ConfigMapVolumeSource.from_dict(obj.get("configMap")) if obj.get("configMap") is not None else None,
            "csi": V1CSIVolumeSource.from_dict(obj.get("csi")) if obj.get("csi") is not None else None,
            "downward_api": V1DownwardAPIVolumeSource.from_dict(obj.get("downwardAPI")) if obj.get("downwardAPI") is not None else None,
            "empty_dir": V1EmptyDirVolumeSource.from_dict(obj.get("emptyDir")) if obj.get("emptyDir") is not None else None,
            "ephemeral": V1EphemeralVolumeSource.from_dict(obj.get("ephemeral")) if obj.get("ephemeral") is not None else None,
            "fc": V1FCVolumeSource.from_dict(obj.get("fc")) if obj.get("fc") is not None else None,
            "flex_volume": V1FlexVolumeSource.from_dict(obj.get("flexVolume")) if obj.get("flexVolume") is not None else None,
            "flocker": V1FlockerVolumeSource.from_dict(obj.get("flocker")) if obj.get("flocker") is not None else None,
            "gce_persistent_disk": V1GCEPersistentDiskVolumeSource.from_dict(obj.get("gcePersistentDisk")) if obj.get("gcePersistentDisk") is not None else None,
            "git_repo": V1GitRepoVolumeSource.from_dict(obj.get("gitRepo")) if obj.get("gitRepo") is not None else None,
            "glusterfs": V1GlusterfsVolumeSource.from_dict(obj.get("glusterfs")) if obj.get("glusterfs") is not None else None,
            "host_path": V1HostPathVolumeSource.from_dict(obj.get("hostPath")) if obj.get("hostPath") is not None else None,
            "iscsi": V1ISCSIVolumeSource.from_dict(obj.get("iscsi")) if obj.get("iscsi") is not None else None,
            "name": obj.get("name"),
            "nfs": V1NFSVolumeSource.from_dict(obj.get("nfs")) if obj.get("nfs") is not None else None,
            "persistent_volume_claim": V1PersistentVolumeClaimVolumeSource.from_dict(obj.get("persistentVolumeClaim")) if obj.get("persistentVolumeClaim") is not None else None,
            "photon_persistent_disk": V1PhotonPersistentDiskVolumeSource.from_dict(obj.get("photonPersistentDisk")) if obj.get("photonPersistentDisk") is not None else None,
            "portworx_volume": V1PortworxVolumeSource.from_dict(obj.get("portworxVolume")) if obj.get("portworxVolume") is not None else None,
            "projected": V1ProjectedVolumeSource.from_dict(obj.get("projected")) if obj.get("projected") is not None else None,
            "quobyte": V1QuobyteVolumeSource.from_dict(obj.get("quobyte")) if obj.get("quobyte") is not None else None,
            "rbd": V1RBDVolumeSource.from_dict(obj.get("rbd")) if obj.get("rbd") is not None else None,
            "scale_io": V1ScaleIOVolumeSource.from_dict(obj.get("scaleIO")) if obj.get("scaleIO") is not None else None,
            "secret": V1SecretVolumeSource.from_dict(obj.get("secret")) if obj.get("secret") is not None else None,
            "storageos": V1StorageOSVolumeSource.from_dict(obj.get("storageos")) if obj.get("storageos") is not None else None,
            "vsphere_volume": V1VsphereVirtualDiskVolumeSource.from_dict(obj.get("vsphereVolume")) if obj.get("vsphereVolume") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from .v1_daemon_set_condition import V1DaemonSetCondition

class V1DaemonSetStatus(BaseModel):
    """
    DaemonSetStatus represents the current status of a daemon set.  # noqa: E501
    """
    collision_count: Optional[StrictInt] = Field(None, alias="collisionCount", description="Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.")
    conditions: Optional[conlist(V1DaemonSetCondition)] = Field(None, description="Represents the latest available observations of a DaemonSet's current state.")
    current_number_scheduled: StrictInt = Field(..., alias="currentNumberScheduled", description="The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/")
    desired_number_scheduled: StrictInt = Field(..., alias="desiredNumberScheduled", description="The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/")
    number_available: Optional[StrictInt] = Field(None, alias="numberAvailable", description="The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds)")
    number_misscheduled: StrictInt = Field(..., alias="numberMisscheduled", description="The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/")
    number_ready: StrictInt = Field(..., alias="numberReady", description="numberReady is the number of nodes that should be running the daemon pod and have one or more of the daemon pod running with a Ready Condition.")
    number_unavailable: Optional[StrictInt] = Field(None, alias="numberUnavailable", description="The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds)")
    observed_generation: Optional[StrictInt] = Field(None, alias="observedGeneration", description="The most recent generation observed by the daemon set controller.")
    updated_number_scheduled: Optional[StrictInt] = Field(None, alias="updatedNumberScheduled", description="The total number of nodes that are running updated daemon pod")
    __properties = ["collisionCount", "conditions", "currentNumberScheduled", "desiredNumberScheduled", "numberAvailable", "numberMisscheduled", "numberReady", "numberUnavailable", "observedGeneration", "updatedNumberScheduled"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1DaemonSetStatus:
        """Create an instance of V1DaemonSetStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item in self.conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['conditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1DaemonSetStatus:
        """Create an instance of V1DaemonSetStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1DaemonSetStatus.parse_obj(obj)

        _obj = V1DaemonSetStatus.parse_obj({
            "collision_count": obj.get("collisionCount"),
            "conditions": [V1DaemonSetCondition.from_dict(_item) for _item in obj.get("conditions")] if obj.get("conditions") is not None else None,
            "current_number_scheduled": obj.get("currentNumberScheduled"),
            "desired_number_scheduled": obj.get("desiredNumberScheduled"),
            "number_available": obj.get("numberAvailable"),
            "number_misscheduled": obj.get("numberMisscheduled"),
            "number_ready": obj.get("numberReady"),
            "number_unavailable": obj.get("numberUnavailable"),
            "observed_generation": obj.get("observedGeneration"),
            "updated_number_scheduled": obj.get("updatedNumberScheduled")
        })
        return _obj





# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: release-1.29
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from .v1_group_subject import V1GroupSubject
from .v1_service_account_subject import V1ServiceAccountSubject
from .v1_user_subject import V1UserSubject

class FlowcontrolV1Subject(BaseModel):
    """
    Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account.  # noqa: E501
    """
    group: Optional[V1GroupSubject] = None
    kind: StrictStr = Field(..., description="`kind` indicates which one of the other fields is non-empty. Required")
    service_account: Optional[V1ServiceAccountSubject] = Field(None, alias="serviceAccount")
    user: Optional[V1UserSubject] = None
    __properties = ["group", "kind", "serviceAccount", "user"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FlowcontrolV1Subject:
        """Create an instance of FlowcontrolV1Subject from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of group
        if self.group:
            _dict['group'] = self.group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of service_account
        if self.service_account:
            _dict['serviceAccount'] = self.service_account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FlowcontrolV1Subject:
        """Create an instance of FlowcontrolV1Subject from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FlowcontrolV1Subject.parse_obj(obj)

        _obj = FlowcontrolV1Subject.parse_obj({
            "group": V1GroupSubject.from_dict(obj.get("group")) if obj.get("group") is not None else None,
            "kind": obj.get("kind"),
            "service_account": V1ServiceAccountSubject.from_dict(obj.get("serviceAccount")) if obj.get("serviceAccount") is not None else None,
            "user": V1UserSubject.from_dict(obj.get("user")) if obj.get("user") is not None else None
        })
        return _obj


